@@ -4,6 +4,10 @@
 # META VERSION 0.1
 
 package require pdwindow 0.1
+if [catch {
+    package require msgcat
+    ::msgcat::mcload po
+}] { puts "patch2svg: i18n failed" }
 
 #package require uriencode
 #package require tinyfileutils
@@ -1673,7 +1677,7 @@ proc focus {winid state} {
 
 proc register {} {
     # create an entry for our "print2svg" in the "file" menu
-    set ::patch2svg::label [_ "Export patch as image..."]
+    set ::patch2svg::label [_ "Export patch as SVG..."]
     set mymenu .menubar.file
     if {$::windowingsystem eq "aqua"} {
         set inserthere 8
@@ -1683,20 +1687,24 @@ proc register {} {
     #$mymenu insert $inserthere separator
     $mymenu insert $inserthere command \
         -label $::patch2svg::label \
+        -state disabled \
         -command {::patch2svg::menu_export $::focused_window}
     # bind all <$::modifier-Key-s> {::deken::open_helpbrowser .helpbrowser2}
     bind PatchWindow <FocusIn> "+::patch2svg::focus %W 1"
     bind PdWindow    <FocusIn> "+::patch2svg::focus %W 0"
 
-    ::pd_connect::register_plugin_dispatch_receiver ::patch2svg::exportall ::patch2svg::exportall
+    set rpdr ::pd_connect::register_plugin_dispatch_receiver
+    if {[info procs $rpdr] == $rpdr} {
+	${rpdr} ::patch2svg::exportall ::patch2svg::exportall
+    }
 
     pdtk_post "loaded patch2svg-plugin\n"
+
+
+
 }
 
 }
 
 
 ::patch2svg::register
-
-
-
