@@ -42,6 +42,13 @@
 /* ------------------------- patcherize ---------------------------- */
 /* ------------ utilities ---------- */
 
+void update_minmax_i(int value, int*min_value, int*max_value) {
+  if(min_value && *min_value > value)
+    *min_value = value;
+  if(max_value && *max_value < value)
+    *max_value = value;
+}
+
 static t_gobj*o2g(t_object*obj) {
   return &(obj->te_g);
 }
@@ -159,8 +166,8 @@ static t_patcherize_connection*create_connection(t_object*from_obj, int from_ind
   return conn;
 }
 static t_patcherize_connection*insert_connection(t_patcherize_connection*iolets,
-						 t_object*from_obj, unsigned int from_index,
-						 t_object*to_obj, unsigned int to_index) {
+                                                 t_object*from_obj, unsigned int from_index,
+                                                 t_object*to_obj, unsigned int to_index) {
   /* check whether iolets already contains from_obj/from_index */
   t_patcherize_connection*cur=iolets, *last=NULL, *conn=NULL;
   if(!cur) {
@@ -185,10 +192,10 @@ static t_patcherize_connection*insert_connection(t_patcherize_connection*iolets,
       /* we sort before current element, so insert! */
       conn->next=cur;
       if(last) {
-	last->next=conn;
+        last->next=conn;
       } else {
-	/* insert beginning */
-	iolets=conn;
+        /* insert beginning */
+        iolets=conn;
       }
       return iolets;
     }
@@ -223,8 +230,8 @@ static t_patcherize_connection*get_object_connections(t_patcherize_connection*io
       t_inlet *in =0;
       conn=obj_nexttraverseoutlet(conn, &dest, &in, &which);
       if (glist_isselected(cnv, &(dest->te_g)) != sel) {
-	/* this is a connection crossing the selection boundary; insert it */
-	iolets=insert_connection(iolets, obj, nout, dest, which);
+        /* this is a connection crossing the selection boundary; insert it */
+        iolets=insert_connection(iolets, obj, nout, dest, which);
       }
     }
   }
@@ -258,13 +265,13 @@ static unsigned int object_getmaxdollar(t_object*obj, unsigned int intermediate)
     else if(A_DOLLSYM == a->a_type) {
       const char*s=a->a_w.w_symbol->s_name;
       while(*s){
-	if('$' == *s) {
-	  char*endptr=0;
-	  long int v=strtol(s+1, &endptr, 10);
-	  s=endptr;
-	  if(v>dollarg)dollarg=v;
-	} else
-	  s++;
+        if('$' == *s) {
+          char*endptr=0;
+          long int v=strtol(s+1, &endptr, 10);
+          s=endptr;
+          if(v>dollarg)dollarg=v;
+        } else
+          s++;
       }
     }
     if(dollarg>intermediate)intermediate=dollarg;
@@ -392,26 +399,26 @@ static int patcherize_single_canvas(t_gobj*gobj, const char*name, int save2file)
 }
 
 static t_glist*patcherize_makesub(t_canvas*cnv,
-				  const char* name, /* subpatch name of filename */
-				  int*save2file_,
-				  int X, int Y,
-				  int xmin, int ymin, int xmax, int ymax,
-				  int xwin, int ywin,
-				  t_patcherize_connections*connections,
-				  unsigned int maxdollarg);
+                                  const char* name, /* subpatch name of filename */
+                                  int*save2file_,
+                                  int X, int Y,
+                                  int xmin, int ymin, int xmax, int ymax,
+                                  int xwin, int ywin,
+                                  t_patcherize_connections*connections,
+                                  unsigned int maxdollarg);
 static t_glist*
 patcherize_makesub_tryagain(t_canvas*cnv,
-			   const char*name, int*save2file,
-			   int X, int Y,
-			   int xmin, int ymin, int xmax, int ymax,
-			   int xwin, int ywin,
-			   t_patcherize_connections*connections,
-			   unsigned int maxdollarg,
-			   t_binbuf*b, t_pd *boundx, t_pd *boundn) {
+                           const char*name, int*save2file,
+                           int X, int Y,
+                           int xmin, int ymin, int xmax, int ymax,
+                           int xwin, int ywin,
+                           t_patcherize_connections*connections,
+                           unsigned int maxdollarg,
+                           t_binbuf*b, t_pd *boundx, t_pd *boundn) {
   /* things went wrong, try again as subpatch */
   t_glist*res=patcherize_makesub(cnv, name, 0,
-				 X, Y, xmin, ymin, xmax, ymax, xwin, ywin,
-				 connections, maxdollarg);
+                                 X, Y, xmin, ymin, xmax, ymax, xwin, ywin,
+                                 connections, maxdollarg);
   if(save2file)*save2file=0;
   s__X.s_thing = boundx;
   s__N.s_thing = boundn;
@@ -419,13 +426,13 @@ patcherize_makesub_tryagain(t_canvas*cnv,
   return res;
 }
 static t_glist*patcherize_makesub(t_canvas*cnv,
-				  const char* name, /* subpatch name of filename */
-				  int*save2file_,
-				  int X, int Y,
-				  int xmin, int ymin, int xmax, int ymax,
-				  int xwin, int ywin,
-				  t_patcherize_connections*connections,
-				  unsigned int maxdollarg) {
+                                  const char* name, /* subpatch name of filename */
+                                  int*save2file_,
+                                  int X, int Y,
+                                  int xmin, int ymin, int xmax, int ymax,
+                                  int xwin, int ywin,
+                                  t_patcherize_connections*connections,
+                                  unsigned int maxdollarg) {
   t_binbuf*b=NULL;
   t_gobj*result=NULL;
   t_patcherize_connection*iolets=NULL;
@@ -439,7 +446,7 @@ static t_glist*patcherize_makesub(t_canvas*cnv,
   s__X.s_thing = &cnv->gl_pd;
   s__N.s_thing = &pd_canvasmaker;
 
-  if(width<200) width=200;
+  if(width <200) width=200;
   if(height<100)height=100;
 
   if (!name || !*name)save2file=0;
@@ -460,7 +467,7 @@ static t_glist*patcherize_makesub(t_canvas*cnv,
   x=20;  y=20;
   while(iolets) {
     binbuf_addv(b, "ssiis;", gensym("#X"), gensym("obj"), x, y,
-		obj_issignaloutlet(iolets->object, iolets->index)?gensym("inlet~"):gensym("inlet"));
+                obj_issignaloutlet(iolets->object, iolets->index)?gensym("inlet~"):gensym("inlet"));
     x+=50;
     iolets=iolets->next;
   }
@@ -468,7 +475,7 @@ static t_glist*patcherize_makesub(t_canvas*cnv,
   x=20; y=height-30;
   while(iolets) {
     binbuf_addv(b, "ssiis;", gensym("#X"), gensym("obj"), x, y,
-		obj_issignaloutlet(iolets->object, iolets->index)?gensym("outlet~"):gensym("outlet"));
+                obj_issignaloutlet(iolets->object, iolets->index)?gensym("outlet~"):gensym("outlet"));
     x+=50;
     iolets=iolets->next;
   }
@@ -495,18 +502,18 @@ static t_glist*patcherize_makesub(t_canvas*cnv,
     if(binbuf_write(b, name, "", 0)) {
       /* things went wrong, try again as subpatch */
       return patcherize_makesub_tryagain(cnv, objname, save2file_,
-					 X, Y, xmin, ymin, xmax, ymax, xwin, ywin,
-					 connections, maxdollarg,
-					 b, boundx, boundn);
+                                         X, Y, xmin, ymin, xmax, ymax, xwin, ywin,
+                                         connections, maxdollarg,
+                                         b, boundx, boundn);
     }
     /* and instantiate the file as an abstraction*/
     if ((fd = canvas_open(cnv, nameptr, "",
-			  dirbuf, &nameptr_res, MAXPDSTRING, 0)) >= 0) {
+                          dirbuf, &nameptr_res, MAXPDSTRING, 0)) >= 0) {
       sys_close(fd);
       nameptr_res[-1]='/';
       if(!strcmp(dirbuf, name)) {
-	strncpy(objname, nameptr_res, MAXPDSTRING-2);
-	objname[strlen(nameptr_res)-3]=0; // strip away ".pd".extension
+        strncpy(objname, nameptr_res, MAXPDSTRING-2);
+        objname[strlen(nameptr_res)-3]=0; // strip away ".pd".extension
       }
     }
     binbuf_clear(b);
@@ -569,19 +576,19 @@ static void canvas_patcherize(t_glist*cnv, t_symbol*s) {
     if(glist_isselected(cnv, gobj)) {
       t_object*obj=pd_checkobject(&gobj->g_pd);
       if(!include_in_patcherization(obj)){
-	/* deselect excluded objects */
-	glist_deselect(cnv, gobj);
-	continue;
+        /* deselect excluded objects */
+        glist_deselect(cnv, gobj);
+        continue;
       }
       if(obj) {
-	int dollarg=get_maxdollarg(obj);
-	int x=obj->te_xpix;
-	int y=obj->te_ypix;
-	xpos+=x;
-	ypos+=y;
-	if(xmin>x)xmin=x;if(xmax<x)xmax=x;
-	if(ymin>y)ymin=y;if(ymax<y)ymax=y;
-	if(dollarg>maxdollarg)maxdollarg=dollarg;
+        int dollarg=get_maxdollarg(obj);
+        int x=obj->te_xpix;
+        int y=obj->te_ypix;
+        xpos+=x;
+        ypos+=y;
+        update_minmax_i(x, &xmin, &xmax);
+        update_minmax_i(y, &ymin, &ymax);
+        if(dollarg>maxdollarg)maxdollarg=dollarg;
       }
       gobjs=resizebytes(gobjs, (objcount)*sizeof(*gobjs), (objcount+1)*sizeof(*gobjs));
       gobjs[objcount]=gobj;
